/*-
 * ~~~~~~licensing~~~~~~
 * ftl-generator
 * ==========
 * Copyright (C) 2020 - 2021 EmDev LLC
 * ==========
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ~~~~~~/licensing~~~~~~
 */
package ru.entaxy.esb.platform.runtime.base.connecting.generator.ftl;

import org.osgi.framework.BundleContext;
import org.osgi.framework.FrameworkUtil;
import org.osgi.framework.ServiceReference;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import ru.entaxy.esb.platform.runtime.base.connecting.generator.Generator;
import ru.entaxy.esb.system.core.template.Template;
import ru.entaxy.esb.system.management.blueprint.generator.Blueprint;
import ru.entaxy.esb.system.management.blueprint.generator.BlueprintGenerator;

import java.util.Map;

public class FTLGenerator implements Generator {

    private static final Logger log = LoggerFactory.getLogger(FTLGenerator.class);

    private BlueprintGenerator blueprintGenerator;
    private Template template;

    @Override
    public Blueprint generate(Map<String, Object> properties) throws Exception {
        Map<String, String> params = (Map)properties;
        log.debug("\nTemplateLocation: {}\nTemplateName: {}\nConnectionName: {}",
                template.getTemplateLocation(), template.getTemplateName(), params.get("connectionName"));
        Blueprint blueprint = getBlueprintGenerator().createBlueprint(template.getTemplateLocation(),
                template.getTemplateName(), params.get("connectionName"), params);
        // TODO: 09.07.2021 Artifact wrapper needed instead of Blueprint (not only blueprint can be return from generator)
        return blueprint;
    }

    public void setTemplate(Template template) {
        this.template = template;
    }

    public BlueprintGenerator getBlueprintGenerator() {
        if (blueprintGenerator == null) {
            BundleContext bundleContext = FrameworkUtil.getBundle(BlueprintGenerator.class).getBundleContext();
            ServiceReference<BlueprintGenerator> blueprintGeneratorServiceReference =
                    bundleContext.getServiceReference(BlueprintGenerator.class);
            blueprintGenerator = bundleContext.getService(blueprintGeneratorServiceReference);
        }
        return blueprintGenerator;
    }

}
