/*-
 * ~~~~~~licensing~~~~~~
 * generator-factory
 * ==========
 * Copyright (C) 2020 - 2021 EmDev LLC
 * ==========
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ~~~~~~/licensing~~~~~~
 */
package ru.entaxy.esb.platform.runtime.base.connecting.generator.factory;

import org.osgi.framework.BundleContext;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import ru.entaxy.esb.platform.runtime.base.connecting.generator.Generator;
import ru.entaxy.esb.platform.runtime.base.connecting.generator.ftl.FTLGenerator;
import ru.entaxy.esb.system.core.template.TemplateImpl;

public class GeneratorFactory {
    private final static Logger log = LoggerFactory.getLogger(GeneratorFactory.class);
    public static final String DEFAULT_GENERATOR = "FTLGenerator";

    public static Generator createGenerator(String usageType, BundleContext bundleContext) {
        return createGenerator(DEFAULT_GENERATOR, usageType, bundleContext);
    }

    public static Generator createGenerator(String generatorType, String usageType, BundleContext bundleContext) {

        log.debug("Creating {} template for {}", usageType, generatorType);
        Generator generator;
        TemplateImpl template = new TemplateImpl();
        template.setTemplateName(usageType);
        template.setBundleContext(bundleContext);

        switch (generatorType) {
            case DEFAULT_GENERATOR:
            default:
                FTLGenerator ftlGenerator = new FTLGenerator();
                ftlGenerator.setTemplate(template);
                generator = ftlGenerator;
        }
        return generator;
    }
}
